/*
   FALCON - The Falcon Programming Language.
   FILE: socket_srv.cpp

   Pluggable application service for Falcon socket module.
   -------------------------------------------------------------------
   Author: Giancarlo Niccolai
   Begin: 2006-05-09 15:50

   -------------------------------------------------------------------
   (C) Copyright 2004: the FALCON developers (see list in AUTHORS file)

   See LICENSE file for licensing details.
*/

/** \file
   Pluggable application service for Falcon socket module.
*/


/* end of socket_srv.cpp */
